@@ -56,7 +56,7 @@ def test_exception_raised_when_unable_to_write_hosts(tmpdir):
     hosts_file = tmpdir.mkdir("etc").join("hosts")
     hosts_file.write("127.0.0.1\tlocalhost\n")
     hosts = Hosts(path=hosts_file.strpath)
-    os.chmod(hosts_file.strpath, 0444)
+    os.chmod(hosts_file.strpath, 0o444)
     new_entry = HostsEntry(entry_type='ipv4', address='123.123.123.123', names=['test.example.com'])
     hosts.add(entries=[new_entry])
     with pytest.raises(exception.UnableToWriteHosts):
@@ -468,3 +468,13 @@ def test_file_import_fails_when_not_readable(tmpdir):
     hosts_entries = Hosts(path=hosts_file.strpath)
     result = hosts_entries.import_file('/invalid_file')
     assert result.get('result') == 'failed'
+
+
+def test_remove_all_matching_multiple(tmpdir):
+    hosts_file = tmpdir.mkdir("etc").join("hosts")
+    hosts_file.write("1.2.3.4\tfoo-1 foo\n"
+                     "2.3.4.5\tfoo-2 foo\n")
+    hosts = Hosts(path=hosts_file.strpath)
+    hosts.remove_all_matching(name="foo")
+    hosts.write()
+    assert hosts_file.read() == ""
